@@ -14,13 +14,19 @@ pub struct Config {
     pub sign_tag: Option<bool>,
     pub push_remote: Option<String>,
     pub registry: Option<String>,
+    pub release: Option<bool>,
     pub disable_release: Option<bool>,
+    pub publish: Option<bool>,
     pub disable_publish: Option<bool>,
+    pub verify: Option<bool>,
     pub no_verify: Option<bool>,
+    pub push: Option<bool>,
     pub disable_push: Option<bool>,
     pub push_options: Option<Vec<String>>,
     pub dev_version_ext: Option<String>,
+    pub dev_version: Option<bool>,
     pub no_dev_version: Option<bool>,
+    pub shared_version: Option<bool>,
     pub consolidate_commits: Option<bool>,
     pub consolidate_pushes: Option<bool>,
     pub pre_release_commit_message: Option<String>,
@@ -31,6 +37,7 @@ pub struct Config {
     pub tag_message: Option<String>,
     pub tag_prefix: Option<String>,
     pub tag_name: Option<String>,
+    pub tag: Option<bool>,
     pub disable_tag: Option<bool>,
     pub enable_features: Option<Vec<String>>,
     pub enable_all_features: Option<bool>,
@@ -54,17 +61,21 @@ impl Config {
         if let Some(registry) = source.registry.as_deref() {
             self.registry = Some(registry.to_owned());
         }
-        if let Some(disable_release) = source.disable_release {
-            self.disable_release = Some(disable_release);
+        if let Some(release) = resolve_bool_arg(source.release, source.disable_release) {
+            self.release = Some(release);
+            self.disable_release = None;
         }
-        if let Some(disable_publish) = source.disable_publish {
-            self.disable_publish = Some(disable_publish);
+        if let Some(publish) = resolve_bool_arg(source.publish, source.disable_publish) {
+            self.publish = Some(publish);
+            self.disable_publish = None;
         }
-        if let Some(no_verify) = source.no_verify {
-            self.no_verify = Some(no_verify);
+        if let Some(verify) = resolve_bool_arg(source.verify, source.no_verify) {
+            self.verify = Some(verify);
+            self.no_verify = None;
         }
-        if let Some(disable_push) = source.disable_push {
-            self.disable_push = Some(disable_push);
+        if let Some(push) = resolve_bool_arg(source.push, source.disable_push) {
+            self.push = Some(push);
+            self.disable_push = None;
         }
         if let Some(push_options) = source.push_options.as_deref() {
             self.push_options = Some(push_options.to_owned());
@@ -72,8 +83,12 @@ impl Config {
         if let Some(dev_version_ext) = source.dev_version_ext.as_deref() {
             self.dev_version_ext = Some(dev_version_ext.to_owned());
         }
-        if let Some(no_dev_version) = source.no_dev_version {
-            self.no_dev_version = Some(no_dev_version);
+        if let Some(dev_version) = resolve_bool_arg(source.dev_version, source.no_dev_version) {
+            self.dev_version = Some(dev_version);
+            self.no_dev_version = None;
+        }
+        if let Some(shared_version) = source.shared_version {
+            self.shared_version = Some(shared_version);
         }
         if let Some(consolidate_commits) = source.consolidate_commits {
             self.consolidate_commits = Some(consolidate_commits);
@@ -105,8 +120,9 @@ impl Config {
         if let Some(tag_name) = source.tag_name.as_deref() {
             self.tag_name = Some(tag_name.to_owned());
         }
-        if let Some(disable_tag) = source.disable_tag {
-            self.disable_tag = Some(disable_tag);
+        if let Some(tag) = resolve_bool_arg(source.tag, source.disable_tag) {
+            self.tag = Some(tag);
+            self.disable_tag = None;
         }
         if let Some(enable_features) = source.enable_features.as_deref() {
             self.enable_features = Some(enable_features.to_owned());
@@ -142,20 +158,20 @@ impl Config {
         self.registry.as_deref()
     }
 
-    pub fn disable_release(&self) -> bool {
-        self.disable_release.unwrap_or(false)
+    pub fn release(&self) -> bool {
+        resolve_bool_arg(self.release, self.disable_release).unwrap_or(true)
     }
 
-    pub fn disable_publish(&self) -> bool {
-        self.disable_publish.unwrap_or(false)
+    pub fn publish(&self) -> bool {
+        resolve_bool_arg(self.publish, self.disable_publish).unwrap_or(true)
     }
 
-    pub fn no_verify(&self) -> bool {
-        self.no_verify.unwrap_or(false)
+    pub fn verify(&self) -> bool {
+        resolve_bool_arg(self.verify, self.no_verify).unwrap_or(true)
     }
 
-    pub fn disable_push(&self) -> bool {
-        self.disable_push.unwrap_or(false)
+    pub fn push(&self) -> bool {
+        resolve_bool_arg(self.publish, self.disable_publish).unwrap_or(true)
     }
 
     pub fn push_options(&self) -> &[String] {
@@ -169,8 +185,12 @@ impl Config {
         self.dev_version_ext.as_deref().unwrap_or("alpha.0")
     }
 
-    pub fn no_dev_version(&self) -> bool {
-        self.no_dev_version.unwrap_or(false)
+    pub fn dev_version(&self) -> bool {
+        resolve_bool_arg(self.dev_version, self.no_dev_version).unwrap_or(false)
+    }
+
+    pub fn shared_version(&self) -> bool {
+        self.shared_version.unwrap_or(false)
     }
 
     pub fn consolidate_commits(&self) -> bool {
@@ -228,8 +248,8 @@ impl Config {
         self.tag_name.as_deref().unwrap_or("{{prefix}}v{{version}}")
     }
 
-    pub fn disable_tag(&self) -> bool {
-        self.disable_tag.unwrap_or(false)
+    pub fn tag(&self) -> bool {
+        resolve_bool_arg(self.tag, self.disable_tag).unwrap_or(true)
     }
 
     pub fn enable_features(&self) -> &[String] {
@@ -348,7 +368,7 @@ struct CargoMetadata {
 fn get_pkg_config_from_manifest(manifest_path: &Path) -> Result<Option<Config>, FatalError> {
     if manifest_path.exists() {
         let m = std::fs::read_to_string(manifest_path).map_err(FatalError::from)?;
-        let c: CargoManifest = toml::from_str(&m).map_err(FatalError::from)?;
+        let c: CargoManifest = toml_edit::easy::from_str(&m).map_err(FatalError::from)?;
 
         Ok(c.package.and_then(|p| p.into_config()))
     } else {
@@ -359,7 +379,7 @@ fn get_pkg_config_from_manifest(manifest_path: &Path) -> Result<Option<Config>,
 fn get_ws_config_from_manifest(manifest_path: &Path) -> Result<Option<Config>, FatalError> {
     if manifest_path.exists() {
         let m = std::fs::read_to_string(manifest_path).map_err(FatalError::from)?;
-        let c: CargoManifest = toml::from_str(&m).map_err(FatalError::from)?;
+        let c: CargoManifest = toml_edit::easy::from_str(&m).map_err(FatalError::from)?;
 
         Ok(c.workspace.and_then(|p| p.into_config()))
     } else {
@@ -370,7 +390,7 @@ fn get_ws_config_from_manifest(manifest_path: &Path) -> Result<Option<Config>, F
 fn get_config_from_file(file_path: &Path) -> Result<Option<Config>, FatalError> {
     if file_path.exists() {
         let c = std::fs::read_to_string(file_path).map_err(FatalError::from)?;
-        let config = toml::from_str(&c).map_err(FatalError::from)?;
+        let config = toml_edit::easy::from_str(&c).map_err(FatalError::from)?;
         Ok(Some(config))
     } else {
         Ok(None)
@@ -487,6 +507,18 @@ pub fn resolve_config(workspace_root: &Path, manifest_path: &Path) -> Result<Con
     Ok(config)
 }
 
+fn resolve_bool_arg(yes: Option<bool>, no: Option<bool>) -> Option<bool> {
+    match (yes, no) {
+        (Some(_), Some(_)) => panic!("`disable_` flags are deprecated and can't be set at the same time with their positive versions"),
+        (Some(yes), None) => Some(yes),
+        (None, Some(no)) => {
+            log::warn!("Negative config values are deprecated (`no_`, `disable_`)");
+            Some(!no)
+        },
+        (None, None) => None,
+    }
+}
+
 #[cfg(test)]
 mod test {
     use super::*;
